# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2020 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================
# IBM starts - 79603
import os
import time

from cloudinit.settings import PER_ALWAYS
from cloudinit import util
from cloudinit import netinfo

frequency = PER_ALWAYS

RMCCTRL = '/opt/rsct/bin/rmcctrl'

def handle(name, _cfg, _cloud, log, _args):
    info = netinfo.netdev_info()
    # making it down and up
    info_len = len(info.keys())

    # IBM start - RTC 74253, 74635 and 74668
    log.debug('Making the ip up')
    # Trying to make the interfaces up
    for info_count in range(info_len):
        try:
            if 'lo' in list(info.keys())[info_count]:
                log.debug('Skipping localhost interface')
                continue
            interface = list(info.keys())[info_count]
            if not info[str(list(info.keys())[info_count])]['ipv4']:
                refresh_ipv6(interface)
        except:
            util.logexc(log, 'Interface is not up')
            pass

    refresh_rmc()


def refresh_ipv6(interface):
    util.subp(['ip', 'link', 'set', interface, 'down'])
    util.subp(['ip', 'link', 'set', interface, 'up'])


def refresh_rmc():
    try:
        util.subp([RMCCTRL, '-z'])
        util.subp([RMCCTRL, '-s'])
    except Exception as e:
        util.logexc(log, 'Failed to refresh the RMC subsystem.')
        raise
# IBM ends
